import React, { useState, useRef, useEffect } from 'react';
import {
  View,
  Text,
  TextInput,
  TouchableOpacity,
  FlatList,
  StyleSheet,
  Modal,
  Keyboard,
} from 'react-native';
import Ionicons from 'react-native-vector-icons/Ionicons';
import { CheckBox } from 'react-native-elements';

export const DropdownSearch = ({
  data,
  onSelect,
  placeholder = 'Select...',
  label,
  labelKey = 'label',
  valueKey = 'value',
  multiSelect = false,
  saveButtonText = 'Save',
  showCheckbox = null,
  showFilter = false,
  placeholderStyle = {},
  downArrowStyle = {}, 
  filterIconStyle = {},
  searchInputStyle = {},
  dropdownButtonstyle={},
  checkboxstyle={},
  checkboxcolor=''
}) => {
  const [isOpen, setIsOpen] = useState(false);
  const [search, setSearch] = useState('');
  const [filteredData, setFilteredData] = useState(data);
  const [selectedItems, setSelectedItems] = useState([]);
  const [selectedLabel, setSelectedLabel] = useState('');
  const [showFilterOptions, setShowFilterOptions] = useState(false);
  const searchInputRef = useRef(null);

  useEffect(() => {
    if (isOpen) {
      setTimeout(() => {
        searchInputRef.current?.focus();
      }, 100);
    }
  }, [isOpen]);

  useEffect(() => {
    if (search == '') {
      setFilteredData(data);
    } else {
      setFilteredData(
        data.filter(item =>
          item[labelKey].toLowerCase().includes(search.toLowerCase())
        )
      );
    }
  }, [search, data]);

  const handleSelect = item => {
    if (multiSelect || showCheckbox == 'multiple') {
      const exists = selectedItems?.find(i => i[valueKey] == item[valueKey]);
      const updatedItems = exists
        ? selectedItems?.filter(i => i[valueKey] !== item[valueKey])
        : [...selectedItems, item];
      setSelectedItems(updatedItems);
    } else {
      setSelectedItems([item]);
      setSelectedLabel(item[labelKey]);
      onSelect(item);
      setIsOpen(false);
      setSearch('');
      Keyboard.dismiss();
    }
  };

  const handleSave = () => {
    onSelect(selectedItems);
    setIsOpen(false);
    setSearch('');
    Keyboard.dismiss();
  };

  const isSelected = item =>
    selectedItems.some(i => i[valueKey] == item[valueKey]);

  const renderSelectedText = () => {
    if (multiSelect || showCheckbox == 'multiple') {
      if (selectedItems.length == 0) return placeholder;
      return selectedItems?.map(i => i[labelKey]).join(', ');
    } else {
      return selectedLabel || placeholder;
    }
  };

  return (
    <>
      {label && <Text style={styles.label}>{label}</Text>}

      <TouchableOpacity style={[styles.dropdownButton,{...dropdownButtonstyle}]} onPress={() => setIsOpen(true)}>
        <Text style={[styles.dropdownButtonText, placeholderStyle]}>
          {renderSelectedText()}
        </Text>
        <Ionicons
          name="chevron-down"
          size={20}
          color="#333"
          style={[styles.icon, downArrowStyle]}
        />
      </TouchableOpacity>

      <Modal
        visible={isOpen}
        animationType="slide"
        transparent
        onRequestClose={() => {
          setIsOpen(false);
          setSearch('');
        }}
      >
        <View style={styles.overlay}>
          <View style={styles.modalContent}>
            <View style={styles.header}>
              {showFilter && (
                <TouchableOpacity
                  onPress={() => setShowFilterOptions(!showFilterOptions)} // Toggle filter options visibility
                >
                  <Ionicons
                    name="filter-outline"
                    size={20}
                    color="#333"
                    style={[styles.filterIcon, filterIconStyle]}
                  />
                </TouchableOpacity>
              )}
              <TextInput
                ref={searchInputRef}
                style={[styles.searchInput, searchInputStyle]}
                placeholder="Search..."
                value={search}
                onChangeText={setSearch}
              />
              <TouchableOpacity onPress={() => { setIsOpen(false); setSearch(''); }}>
                <Ionicons name="close" size={24} color="#333" />
              </TouchableOpacity>
            </View>

            {showFilterOptions && ( // Conditionally render filter options if showFilterOptions is true
              <View style={styles.filterOptions}>
                {/* Add filter options here (e.g., additional inputs, checkboxes, etc.) */}
                <Text>Filter by:</Text>
                <TextInput style={styles.filterInput} placeholder="Enter filter" />
                {/* You can add more filter inputs here */}
              </View>
            )}

            <FlatList
              keyboardShouldPersistTaps="handled"
              data={filteredData}
              keyExtractor={(item, index) => item[valueKey]?.toString() || index.toString()}
              renderItem={({ item }) => (
                <TouchableOpacity style={styles.item} onPress={() => handleSelect(item)}>
                  <View style={styles.itemRow}>
                    <Text style={[styles.itemText, { color: isSelected(item) ? '#007bff' : '#000' }]}>
                      {item[labelKey]}
                    </Text>
                    {showCheckbox && (
                      <CheckBox
                        checked={isSelected(item)}
                        onPress={() => handleSelect(item)}
                        checkedColor={checkboxcolor || "#007bff"}
                        containerStyle={[styles.checkbox,{...checkboxstyle}]}
                      />
                    )}
                  </View>
                </TouchableOpacity>
              )}
            />

            {(multiSelect || showCheckbox == 'multiple') && (
              <TouchableOpacity style={styles.saveButton} onPress={handleSave}>
                <Text style={styles.saveButtonText}>{saveButtonText}</Text>
              </TouchableOpacity>
            )}
          </View>
        </View>
      </Modal>
    </>
  );
};

const styles = StyleSheet.create({
  label: {
    marginBottom: 4,
    fontSize: 16,
    color: '#333',
  },
  dropdownButton: {
    padding: 12,
    borderWidth: 1,
    borderColor: '#ccc',
    borderRadius: 8,
    backgroundColor: '#fff',
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
    width:'60%',
    alignSelf:'center'
  },
  dropdownButtonText: {
    fontSize: 16,
    color: '#333',
    flexShrink: 1,
  },
  icon: {
    marginLeft: 8,
  },
  overlay: {
    flex: 1,
    backgroundColor: 'rgba(0,0,0,0.2)',
    justifyContent: 'center',
    padding: 20,
  },
  modalContent: {
    backgroundColor: '#fff',
    borderRadius: 12,
    padding: 16,
    maxHeight: '80%',
    
  },
  header: {
    flexDirection: 'row',
    alignItems: 'center',
    marginBottom: 12,
    borderBottomWidth: 1,
    borderBottomColor: '#ccc',
  },
  searchInput: {
    flex: 1,
    paddingVertical: 8,
    fontSize: 16,
  },
  filterIcon: {
    marginRight: 8,
  },
  filterOptions: {
    marginTop: 12,
    paddingVertical: 8,
    borderTopWidth: 1,
    borderTopColor: '#ccc',
  },
  filterInput: {
    marginTop: 8,
    paddingVertical: 8,
    fontSize: 16,
    borderWidth: 1,
    borderColor: '#ccc',
    borderRadius: 4,
  },
  item: {
    paddingVertical: 12,
    borderBottomWidth: 0.5,
    borderBottomColor: '#eee',
  },
  itemRow: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
  },
  itemText: {
    fontSize: 16,
    flex: 1,
  },
  checkbox: {
    padding: 0,
    margin: 0,
  },
  saveButton: {
    marginTop: 16,
    backgroundColor: '#007bff',
    paddingVertical: 10,
    borderRadius: 8,
    alignItems: 'center',
  },
  saveButtonText: {
    color: '#fff',
    fontSize: 16,
  },
});
